@@ -38,7 +38,6 @@ import org.eclipse.che.commons.env.EnvironmentContext;
 import org.eclipse.che.commons.json.JsonHelper;
 import org.eclipse.che.commons.json.JsonParseException;
 import org.eclipse.che.security.oauth.shared.OAuthTokenProvider;
-import org.eclipse.che.security.oauth.shared.User;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -209,15 +208,6 @@ public abstract class OAuthAuthenticator {
     }
   }
 
-  /**
-   * Get user info.
-   *
-   * @param accessToken oauth access token
-   * @return user info
-   * @throws OAuthAuthenticationException if fail to get user info
-   */
-  public abstract User getUser(OAuthToken accessToken) throws OAuthAuthenticationException;
-
   /**
    * Creates a new {@link AuthorizationCodeTokenRequest} for the given authorization code. Intended
    * to be overridden by subclasses to customize the request.
