@@ -22,7 +22,7 @@ import javax.inject.Inject;
 import javax.inject.Singleton;
 import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.core.BadRequestException;
-import org.eclipse.che.api.factory.server.DefaultFactoryParameterResolver;
+import org.eclipse.che.api.factory.server.RawDevfileUrlFactoryParameterResolver;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.RemoteFactoryUrl;
 import org.eclipse.che.api.factory.server.urlfactory.URLFactoryBuilder;
@@ -43,7 +43,7 @@ import org.eclipse.che.api.workspace.shared.dto.devfile.SourceDto;
  */
 @Singleton
 public class BitbucketServerAuthorizingFactoryParametersResolver
-    extends DefaultFactoryParameterResolver {
+    extends RawDevfileUrlFactoryParameterResolver {
 
   /** Parser which will allow to check validity of URLs and create objects. */
   private final BitbucketServerURLParser bitbucketURLParser;
